%%%----------------------------------------------------------------------
%%% File    : manderlbot.erl
%%% Author  : Dimitri Fontaine <dim@tuxfamily.org>
%%% Purpose : This app is an IRC bot
%%% Created : 19 Feb 2002 by Dimitri Fontaine <dim@tuxfamily.org>
%%%----------------------------------------------------------------------
%%%
%%% This file is part of Manderlbot.
%%%
%%% Manderlbot is free software; you can redistribute it and/or modify
%%% it under the terms of the GNU General Public License as published by
%%% the Free Software Foundation; either version 2 of the License, or
%%% (at your option) any later version.
%%%
%%% Manderlbot is distributed in the hope that it will be useful,
%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%%% GNU General Public License for more details.
%%%
%%% See LICENSE for detailled license
%%%
%%% In addition, as a special exception, you have the permission to
%%% link the code of this program with any library released under
%%% the EPL license and distribute linked combinations including
%%% the two. If you modify this file, you may extend this exception
%%% to your version of the file, but you are not obligated to do
%%% so.  If you do not wish to do so, delete this exception
%%% statement from your version.
%%%
%%%----------------------------------------------------------------------

-module(manderlbot).
-author('dim@tuxfamily.org').

-include("config.hrl").

-behaviour(application).

%% application callbacks
-export([start/2, stop/1]).

%%%----------------------------------------------------------------------
%%% Callback functions from application
%%%----------------------------------------------------------------------

%%----------------------------------------------------------------------
%% Func: start/2
%% Returns: {ok, Pid}        |
%%          {ok, Pid, State} |
%%          {error, Reason}   
%%----------------------------------------------------------------------
start(Type, StartArgs) ->
    %%case mdb_sup:start_link(StartArgs) of
    case manderlbot_sup:start_link() of
	{ok, Pid} -> 
	    %% Do our stuff
	    init(),
	    {ok, Pid};
	Error ->
	    Error
    end.

%%----------------------------------------------------------------------
%% Func: stop/1
%% Returns: any 
%%----------------------------------------------------------------------
stop(State) ->
    ok.

%%%----------------------------------------------------------------------
%%% Internal functions
%%%----------------------------------------------------------------------
init() ->
    %% Start a bot per chan
    {ok, Conf} = config_srv:getConf(),

    Name      = Conf#config.name,
    Controler = Conf#config.controler,

    lists:foreach(fun(Server = #server{host     = Host,
				       port     = Port,
				       passwd   = Passwd,
				       channels = ChanList}) ->

			  StartBot = fun(Chan = #channel{}) ->
					     mdb_botlist:add(Name,
							     Controler,
							     Host,
							     Port,
							     Passwd,
							     Chan)
				     end,
			  lists:foreach(StartBot, ChanList)
		  end,
		  Conf#config.servers),
    ok.
